@@ -458,4 +458,9 @@ chr1	100	200	a2	2	-" > exp
 $BT intersect -a a.bed -b a.bam > obs
 
 
-rm one_block.bam two_blocks.bam three_blocks.bam
\ No newline at end of file
+rm one_block.bam two_blocks.bam three_blocks.bam
+
+
+cd multi_intersect
+bash test-multi_intersect.sh
+cd ..
\ No newline at end of file
